
# opstrat

![PyPI](https://img.shields.io/pypi/v/opstrat)
![PyPI - License](https://img.shields.io/pypi/l/opstrat)
![GitHub top language](https://img.shields.io/github/languages/top/abhijith-git/opstrat) 
![GitHub Repo stars](https://img.shields.io/github/stars/abhijith-git/opstrat?style=social)
![Twitter Follow](https://img.shields.io/twitter/follow/abhijith_abcd?style=social)

Python library for visualizing options.


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install opstrat.

```bash
pip install opstrat
```

## Usage

```python
import opstrat

opstrat.basic.option_plotter() # plots a basic option payoff diagram
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Content License
[MIT](https://choosealicense.com/licenses/mit/)
